==> microsoft-graph-beta-6.43.0-sources.jar: com/microsoft/graph/beta/models/EducationAiFeedbackContentSettings.java <==
package com.microsoft.graph.beta.models;

import com.microsoft.kiota.serialization.AdditionalDataHolder;
import com.microsoft.kiota.serialization.Parsable;
import com.microsoft.kiota.serialization.ParseNode;
import com.microsoft.kiota.serialization.SerializationWriter;
import com.microsoft.kiota.store.BackedModel;
import com.microsoft.kiota.store.BackingStore;
import com.microsoft.kiota.store.BackingStoreFactorySingleton;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
@jakarta.annotation.Generated("com.microsoft.kiota")
public class EducationAiFeedbackContentSettings implements AdditionalDataHolder, BackedModel, Parsable {
    /**
     * Stores model information.
     */
    @jakarta.annotation.Nonnull
    protected BackingStore backingStore;
    /**
     * Instantiates a new {@link EducationAiFeedbackContentSettings} and sets the default values.
     */
    public EducationAiFeedbackContentSettings() {
        this.backingStore = BackingStoreFactorySingleton.instance.createBackingStore();
        this.setAdditionalData(new HashMap<>());
    }
    /**
     * Creates a new instance of the appropriate class based on discriminator value
     * @param parseNode The parse node to use to read the discriminator value and create the object
     * @return a {@link EducationAiFeedbackContentSettings}
     */
    @jakarta.annotation.Nonnull
    public static EducationAiFeedbackContentSettings createFromDiscriminatorValue(@jakarta.annotation.Nonnull final ParseNode parseNode) {
        Objects.requireNonNull(parseNode);
        return new EducationAiFeedbackContentSettings();
    }
    /**
     * Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @return a {@link Map<String, Object>}
     */
    @jakarta.annotation.Nonnull
    public Map<String, Object> getAdditionalData() {
        Map<String, Object> value = this.backingStore.get("additionalData");
        if(value == null) {
            value = new HashMap<>();
            this.setAdditionalData(value);
        }
        return value;
    }
    /**
     * Gets the backingStore property value. Stores model information.
     * @return a {@link BackingStore}
     */
    @jakarta.annotation.Nonnull
    public BackingStore getBackingStore() {
        return this.backingStore;
    }
    /**
     * The deserialization information for the current model
     * @return a {@link Map<String, java.util.function.Consumer<ParseNode>>}
     */
    @jakarta.annotation.Nonnull
    public Map<String, java.util.function.Consumer<ParseNode>> getFieldDeserializers() {
        final HashMap<String, java.util.function.Consumer<ParseNode>> deserializerMap = new HashMap<String, java.util.function.Consumer<ParseNode>>(4);
        deserializerMap.put("isMessageClarityEnabled", (n) -> { this.setIsMessageClarityEnabled(n.getBooleanValue()); });
        deserializerMap.put("isQualityOfInformationEnabled", (n) -> { this.setIsQualityOfInformationEnabled(n.getBooleanValue()); });
        deserializerMap.put("isSpeechOrganizationEnabled", (n) -> { this.setIsSpeechOrganizationEnabled(n.getBooleanValue()); });
        deserializerMap.put("@odata.type", (n) -> { this.setOdataType(n.getStringValue()); });
        return deserializerMap;
    }
    /**
     * Gets the isMessageClarityEnabled property value. The isMessageClarityEnabled property
     * @return a {@link Boolean}
     */
    @jakarta.annotation.Nullable
    public Boolean getIsMessageClarityEnabled() {
        return this.backingStore.get("isMessageClarityEnabled");
    }
    /**
     * Gets the isQualityOfInformationEnabled property value. The isQualityOfInformationEnabled property
     * @return a {@link Boolean}
     */
    @jakarta.annotation.Nullable
    public Boolean getIsQualityOfInformationEnabled() {
        return this.backingStore.get("isQualityOfInformationEnabled");
    }
    /**
     * Gets the isSpeechOrganizationEnabled property value. The isSpeechOrganizationEnabled property
     * @return a {@link Boolean}
     */
    @jakarta.annotation.Nullable
    public Boolean getIsSpeechOrganizationEnabled() {
        return this.backingStore.get("isSpeechOrganizationEnabled");
    }
    /**
     * Gets the @odata.type property value. The OdataType property
     * @return a {@link String}
     */
    @jakarta.annotation.Nullable
    public String getOdataType() {
        return this.backingStore.get("odataType");
    }
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    public void serialize(@jakarta.annotation.Nonnull final SerializationWriter writer) {
        Objects.requireNonNull(writer);
        writer.writeBooleanValue("isMessageClarityEnabled", this.getIsMessageClarityEnabled());
        writer.writeBooleanValue("isQualityOfInformationEnabled", this.getIsQualityOfInformationEnabled());
        writer.writeBooleanValue("isSpeechOrganizationEnabled", this.getIsSpeechOrganizationEnabled());
        writer.writeStringValue("@odata.type", this.getOdataType());
        writer.writeAdditionalData(this.getAdditionalData());
    }
    /**
     * Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    public void setAdditionalData(@jakarta.annotation.Nullable final Map<String, Object> value) {
        this.backingStore.set("additionalData", value);
    }
    /**
     * Sets the backingStore property value. Stores model information.
     * @param value Value to set for the backingStore property.
     */
    public void setBackingStore(@jakarta.annotation.Nonnull final BackingStore value) {
        Objects.requireNonNull(value);
        this.backingStore = value;
    }
    /**
     * Sets the isMessageClarityEnabled property value. The isMessageClarityEnabled property
     * @param value Value to set for the isMessageClarityEnabled property.
     */
    public void setIsMessageClarityEnabled(@jakarta.annotation.Nullable final Boolean value) {
        this.backingStore.set("isMessageClarityEnabled", value);
    }
    /**
     * Sets the isQualityOfInformationEnabled property value. The isQualityOfInformationEnabled property
     * @param value Value to set for the isQualityOfInformationEnabled property.
     */
    public void setIsQualityOfInformationEnabled(@jakarta.annotation.Nullable final Boolean value) {
        this.backingStore.set("isQualityOfInformationEnabled", value);
    }
    /**
     * Sets the isSpeechOrganizationEnabled property value. The isSpeechOrganizationEnabled property
     * @param value Value to set for the isSpeechOrganizationEnabled property.
     */
    public void setIsSpeechOrganizationEnabled(@jakarta.annotation.Nullable final Boolean value) {
        this.backingStore.set("isSpeechOrganizationEnabled", value);
    }
    /**
     * Sets the @odata.type property value. The OdataType property
     * @param value Value to set for the @odata.type property.
     */
    public void setOdataType(@jakarta.annotation.Nullable final String value) {
        this.backingStore.set("odataType", value);
    }
}

==> microsoft-graph-beta-6.45.0-sources.jar: com/microsoft/graph/beta/models/EducationAiFeedbackContentSettings.java <==
package com.microsoft.graph.beta.models;

import com.microsoft.kiota.serialization.AdditionalDataHolder;
import com.microsoft.kiota.serialization.Parsable;
import com.microsoft.kiota.serialization.ParseNode;
import com.microsoft.kiota.serialization.SerializationWriter;
import com.microsoft.kiota.store.BackedModel;
import com.microsoft.kiota.store.BackingStore;
import com.microsoft.kiota.store.BackingStoreFactorySingleton;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
@jakarta.annotation.Generated("com.microsoft.kiota")
public class EducationAiFeedbackContentSettings implements AdditionalDataHolder, BackedModel, Parsable {
    /**
     * Stores model information.
     */
    @jakarta.annotation.Nonnull
    protected BackingStore backingStore;
    /**
     * Instantiates a new {@link EducationAiFeedbackContentSettings} and sets the default values.
     */
    public EducationAiFeedbackContentSettings() {
        this.backingStore = BackingStoreFactorySingleton.instance.createBackingStore();
        this.setAdditionalData(new HashMap<>());
    }
    /**
     * Creates a new instance of the appropriate class based on discriminator value
     * @param parseNode The parse node to use to read the discriminator value and create the object
     * @return a {@link EducationAiFeedbackContentSettings}
     */
    @jakarta.annotation.Nonnull
    public static EducationAiFeedbackContentSettings createFromDiscriminatorValue(@jakarta.annotation.Nonnull final ParseNode parseNode) {
        Objects.requireNonNull(parseNode);
        return new EducationAiFeedbackContentSettings();
    }
    /**
     * Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @return a {@link Map<String, Object>}
     */
    @jakarta.annotation.Nonnull
    public Map<String, Object> getAdditionalData() {
        Map<String, Object> value = this.backingStore.get("additionalData");
        if(value == null) {
            value = new HashMap<>();
            this.setAdditionalData(value);
        }
        return value;
    }
    /**
     * Gets the backingStore property value. Stores model information.
     * @return a {@link BackingStore}
     */
    @jakarta.annotation.Nonnull
    public BackingStore getBackingStore() {
        return this.backingStore;
    }
    /**
     * The deserialization information for the current model
     * @return a {@link Map<String, java.util.function.Consumer<ParseNode>>}
     */
    @jakarta.annotation.Nonnull
    public Map<String, java.util.function.Consumer<ParseNode>> getFieldDeserializers() {
        final HashMap<String, java.util.function.Consumer<ParseNode>> deserializerMap = new HashMap<String, java.util.function.Consumer<ParseNode>>(4);
        deserializerMap.put("isMessageClarityEnabled", (n) -> { this.setIsMessageClarityEnabled(n.getBooleanValue()); });
        deserializerMap.put("isQualityOfInformationEnabled", (n) -> { this.setIsQualityOfInformationEnabled(n.getBooleanValue()); });
        deserializerMap.put("isSpeechOrganizationEnabled", (n) -> { this.setIsSpeechOrganizationEnabled(n.getBooleanValue()); });
        deserializerMap.put("@odata.type", (n) -> { this.setOdataType(n.getStringValue()); });
        return deserializerMap;
    }
    /**
     * Gets the isMessageClarityEnabled property value. Indicates whether the student should receive feedback on their message clarity from the AI feedback.
     * @return a {@link Boolean}
     */
    @jakarta.annotation.Nullable
    public Boolean getIsMessageClarityEnabled() {
        return this.backingStore.get("isMessageClarityEnabled");
    }
    /**
     * Gets the isQualityOfInformationEnabled property value. Indicates whether the student should receive feedback on their quality of information from the AI feedback.
     * @return a {@link Boolean}
     */
    @jakarta.annotation.Nullable
    public Boolean getIsQualityOfInformationEnabled() {
        return this.backingStore.get("isQualityOfInformationEnabled");
    }
    /**
     * Gets the isSpeechOrganizationEnabled property value. Indicates whether the student should receive feedback on their speech organization from the AI feedback.
     * @return a {@link Boolean}
     */
    @jakarta.annotation.Nullable
    public Boolean getIsSpeechOrganizationEnabled() {
        return this.backingStore.get("isSpeechOrganizationEnabled");
    }
    /**
     * Gets the @odata.type property value. The OdataType property
     * @return a {@link String}
     */
    @jakarta.annotation.Nullable
    public String getOdataType() {
        return this.backingStore.get("odataType");
    }
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    public void serialize(@jakarta.annotation.Nonnull final SerializationWriter writer) {
        Objects.requireNonNull(writer);
        writer.writeBooleanValue("isMessageClarityEnabled", this.getIsMessageClarityEnabled());
        writer.writeBooleanValue("isQualityOfInformationEnabled", this.getIsQualityOfInformationEnabled());
        writer.writeBooleanValue("isSpeechOrganizationEnabled", this.getIsSpeechOrganizationEnabled());
        writer.writeStringValue("@odata.type", this.getOdataType());
        writer.writeAdditionalData(this.getAdditionalData());
    }
    /**
     * Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    public void setAdditionalData(@jakarta.annotation.Nullable final Map<String, Object> value) {
        this.backingStore.set("additionalData", value);
    }
    /**
     * Sets the backingStore property value. Stores model information.
     * @param value Value to set for the backingStore property.
     */
    public void setBackingStore(@jakarta.annotation.Nonnull final BackingStore value) {
        Objects.requireNonNull(value);
        this.backingStore = value;
    }
    /**
     * Sets the isMessageClarityEnabled property value. Indicates whether the student should receive feedback on their message clarity from the AI feedback.
     * @param value Value to set for the isMessageClarityEnabled property.
     */
    public void setIsMessageClarityEnabled(@jakarta.annotation.Nullable final Boolean value) {
        this.backingStore.set("isMessageClarityEnabled", value);
    }
    /**
     * Sets the isQualityOfInformationEnabled property value. Indicates whether the student should receive feedback on their quality of information from the AI feedback.
     * @param value Value to set for the isQualityOfInformationEnabled property.
     */
    public void setIsQualityOfInformationEnabled(@jakarta.annotation.Nullable final Boolean value) {
        this.backingStore.set("isQualityOfInformationEnabled", value);
    }
    /**
     * Sets the isSpeechOrganizationEnabled property value. Indicates whether the student should receive feedback on their speech organization from the AI feedback.
     * @param value Value to set for the isSpeechOrganizationEnabled property.
     */
    public void setIsSpeechOrganizationEnabled(@jakarta.annotation.Nullable final Boolean value) {
        this.backingStore.set("isSpeechOrganizationEnabled", value);
    }
    /**
     * Sets the @odata.type property value. The OdataType property
     * @param value Value to set for the @odata.type property.
     */
    public void setOdataType(@jakarta.annotation.Nullable final String value) {
        this.backingStore.set("odataType", value);
    }
}
